//! Tests auto-converted from "sass-spec/spec/core_functions/color/adjust_color"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("adjust_color")
}

mod error;
